@@ -58,6 +58,7 @@ static = [ 'style.css',
            'jquery.min.js',
            'ui-icons_222222_256x240.png',
            'magic.js',
+           'favicon.png'
          ]
 for s in static:
     shutil.copy(os.path.join(template_path, s), output_path)
@@ -104,8 +105,10 @@ def render_template(name, namespaces, target=None):
 
 namespaces = { 'spec': spec }
 
-render_template('generic-types.html', namespaces)
-render_template('errors.html', namespaces)
+if len(spec.generic_types) > 0:
+    render_template('generic-types.html', namespaces)
+if len(spec.errors) > 0:
+    render_template('errors.html', namespaces)
 render_template('interfaces.html', namespaces)
 render_template('fullindex.html', namespaces)
 
